# PulpFileClient::DistributionsFileApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](DistributionsFileApi.md#create) | **POST** /pulp/api/v3/distributions/file/file/ | Create a file distribution
[**delete**](DistributionsFileApi.md#delete) | **DELETE** {file_file_distribution_href} | Delete a file distribution
[**list**](DistributionsFileApi.md#list) | **GET** /pulp/api/v3/distributions/file/file/ | List file distributions
[**partial_update**](DistributionsFileApi.md#partial_update) | **PATCH** {file_file_distribution_href} | Update a file distribution
[**read**](DistributionsFileApi.md#read) | **GET** {file_file_distribution_href} | Inspect a file distribution
[**update**](DistributionsFileApi.md#update) | **PUT** {file_file_distribution_href} | Update a file distribution



## create

> AsyncOperationResponse create(file_file_distribution)

Create a file distribution

Trigger an asynchronous create task

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::DistributionsFileApi.new
file_file_distribution = PulpFileClient::FileFileDistribution.new # FileFileDistribution | 

begin
  #Create a file distribution
  result = api_instance.create(file_file_distribution)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling DistributionsFileApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_distribution** | [**FileFileDistribution**](FileFileDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(file_file_distribution_href, opts)

Delete a file distribution

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::DistributionsFileApi.new
file_file_distribution_href = 'file_file_distribution_href_example' # String | 
opts = {
  base_path: 'base_path_example', # String | base_path
  base_path__contains: 'base_path__contains_example', # String | base_path__contains
  base_path__icontains: 'base_path__icontains_example', # String | base_path__icontains
  base_path__in: 'base_path__in_example', # String | base_path__in
  name: 'name_example', # String | name
  name__in: 'name__in_example', # String | name__in
  ordering: 'ordering_example' # String | Which field to use when ordering the results.
}

begin
  #Delete a file distribution
  result = api_instance.delete(file_file_distribution_href, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling DistributionsFileApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_distribution_href** | **String**|  | 
 **base_path** | **String**| base_path | [optional] 
 **base_path__contains** | **String**| base_path__contains | [optional] 
 **base_path__icontains** | **String**| base_path__icontains | [optional] 
 **base_path__in** | **String**| base_path__in | [optional] 
 **name** | **String**| name | [optional] 
 **name__in** | **String**| name__in | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> InlineResponse2001 list(opts)

List file distributions

 FileDistributions host File Publications which makes the metadata and the referenced File Content available to HTTP clients. Additionally, a FileDistribution with an associated FilePublication can be the target url of a File Remote , allowing another instance of Pulp to sync the content.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::DistributionsFileApi.new
opts = {
  base_path: 'base_path_example', # String | base_path
  base_path__contains: 'base_path__contains_example', # String | base_path__contains
  base_path__icontains: 'base_path__icontains_example', # String | base_path__icontains
  base_path__in: 'base_path__in_example', # String | base_path__in
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | name
  name__in: 'name__in_example', # String | name__in
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List file distributions
  result = api_instance.list(opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling DistributionsFileApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **base_path** | **String**| base_path | [optional] 
 **base_path__contains** | **String**| base_path__contains | [optional] 
 **base_path__icontains** | **String**| base_path__icontains | [optional] 
 **base_path__in** | **String**| base_path__in | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| name | [optional] 
 **name__in** | **String**| name__in | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**InlineResponse2001**](InlineResponse2001.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(file_file_distribution_href, patchedfile_file_distribution, opts)

Update a file distribution

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::DistributionsFileApi.new
file_file_distribution_href = 'file_file_distribution_href_example' # String | 
patchedfile_file_distribution = PulpFileClient::PatchedfileFileDistribution.new # PatchedfileFileDistribution | 
opts = {
  base_path: 'base_path_example', # String | base_path
  base_path__contains: 'base_path__contains_example', # String | base_path__contains
  base_path__icontains: 'base_path__icontains_example', # String | base_path__icontains
  base_path__in: 'base_path__in_example', # String | base_path__in
  name: 'name_example', # String | name
  name__in: 'name__in_example', # String | name__in
  ordering: 'ordering_example' # String | Which field to use when ordering the results.
}

begin
  #Update a file distribution
  result = api_instance.partial_update(file_file_distribution_href, patchedfile_file_distribution, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling DistributionsFileApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_distribution_href** | **String**|  | 
 **patchedfile_file_distribution** | [**PatchedfileFileDistribution**](PatchedfileFileDistribution.md)|  | 
 **base_path** | **String**| base_path | [optional] 
 **base_path__contains** | **String**| base_path__contains | [optional] 
 **base_path__icontains** | **String**| base_path__icontains | [optional] 
 **base_path__in** | **String**| base_path__in | [optional] 
 **name** | **String**| name | [optional] 
 **name__in** | **String**| name__in | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> FileFileDistributionResponse read(file_file_distribution_href, opts)

Inspect a file distribution

 FileDistributions host File Publications which makes the metadata and the referenced File Content available to HTTP clients. Additionally, a FileDistribution with an associated FilePublication can be the target url of a File Remote , allowing another instance of Pulp to sync the content.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::DistributionsFileApi.new
file_file_distribution_href = 'file_file_distribution_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a file distribution
  result = api_instance.read(file_file_distribution_href, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling DistributionsFileApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_distribution_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**FileFileDistributionResponse**](FileFileDistributionResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(file_file_distribution_href, file_file_distribution, opts)

Update a file distribution

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::DistributionsFileApi.new
file_file_distribution_href = 'file_file_distribution_href_example' # String | 
file_file_distribution = PulpFileClient::FileFileDistribution.new # FileFileDistribution | 
opts = {
  base_path: 'base_path_example', # String | base_path
  base_path__contains: 'base_path__contains_example', # String | base_path__contains
  base_path__icontains: 'base_path__icontains_example', # String | base_path__icontains
  base_path__in: 'base_path__in_example', # String | base_path__in
  name: 'name_example', # String | name
  name__in: 'name__in_example', # String | name__in
  ordering: 'ordering_example' # String | Which field to use when ordering the results.
}

begin
  #Update a file distribution
  result = api_instance.update(file_file_distribution_href, file_file_distribution, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling DistributionsFileApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_distribution_href** | **String**|  | 
 **file_file_distribution** | [**FileFileDistribution**](FileFileDistribution.md)|  | 
 **base_path** | **String**| base_path | [optional] 
 **base_path__contains** | **String**| base_path__contains | [optional] 
 **base_path__icontains** | **String**| base_path__icontains | [optional] 
 **base_path__in** | **String**| base_path__in | [optional] 
 **name** | **String**| name | [optional] 
 **name__in** | **String**| name__in | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

