# PulpFileClient::RemotesFileApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](RemotesFileApi.md#create) | **POST** /pulp/api/v3/remotes/file/file/ | Create a file remote
[**delete**](RemotesFileApi.md#delete) | **DELETE** {file_file_remote_href} | Delete a file remote
[**list**](RemotesFileApi.md#list) | **GET** /pulp/api/v3/remotes/file/file/ | List file remotes
[**partial_update**](RemotesFileApi.md#partial_update) | **PATCH** {file_file_remote_href} | Update a file remote
[**read**](RemotesFileApi.md#read) | **GET** {file_file_remote_href} | Inspect a file remote
[**update**](RemotesFileApi.md#update) | **PUT** {file_file_remote_href} | Update a file remote



## create

> FileFileRemoteResponse create(file_file_remote)

Create a file remote

 FileRemote represents an external source of File Content.  The target url of a FileRemote must contain a file manifest, which contains the metadata for all files at the source.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::RemotesFileApi.new
file_file_remote = PulpFileClient::FileFileRemote.new # FileFileRemote | 

begin
  #Create a file remote
  result = api_instance.create(file_file_remote)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling RemotesFileApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_remote** | [**FileFileRemote**](FileFileRemote.md)|  | 

### Return type

[**FileFileRemoteResponse**](FileFileRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(file_file_remote_href, opts)

Delete a file remote

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::RemotesFileApi.new
file_file_remote_href = 'file_file_remote_href_example' # String | 
opts = {
  name: 'name_example', # String | name
  name__in: 'name__in_example', # String | name__in
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_last_updated: 'pulp_last_updated_example', # String | pulp_last_updated
  pulp_last_updated__gt: 'pulp_last_updated__gt_example', # String | pulp_last_updated__gt
  pulp_last_updated__gte: 'pulp_last_updated__gte_example', # String | pulp_last_updated__gte
  pulp_last_updated__lt: 'pulp_last_updated__lt_example', # String | pulp_last_updated__lt
  pulp_last_updated__lte: 'pulp_last_updated__lte_example', # String | pulp_last_updated__lte
  pulp_last_updated__range: 'pulp_last_updated__range_example' # String | pulp_last_updated__range
}

begin
  #Delete a file remote
  result = api_instance.delete(file_file_remote_href, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling RemotesFileApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_remote_href** | **String**|  | 
 **name** | **String**| name | [optional] 
 **name__in** | **String**| name__in | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_last_updated** | **String**| pulp_last_updated | [optional] 
 **pulp_last_updated__gt** | **String**| pulp_last_updated__gt | [optional] 
 **pulp_last_updated__gte** | **String**| pulp_last_updated__gte | [optional] 
 **pulp_last_updated__lt** | **String**| pulp_last_updated__lt | [optional] 
 **pulp_last_updated__lte** | **String**| pulp_last_updated__lte | [optional] 
 **pulp_last_updated__range** | **String**| pulp_last_updated__range | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> InlineResponse2005 list(opts)

List file remotes

 FileRemote represents an external source of File Content.  The target url of a FileRemote must contain a file manifest, which contains the metadata for all files at the source.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::RemotesFileApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | name
  name__in: 'name__in_example', # String | name__in
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_last_updated: 'pulp_last_updated_example', # String | pulp_last_updated
  pulp_last_updated__gt: 'pulp_last_updated__gt_example', # String | pulp_last_updated__gt
  pulp_last_updated__gte: 'pulp_last_updated__gte_example', # String | pulp_last_updated__gte
  pulp_last_updated__lt: 'pulp_last_updated__lt_example', # String | pulp_last_updated__lt
  pulp_last_updated__lte: 'pulp_last_updated__lte_example', # String | pulp_last_updated__lte
  pulp_last_updated__range: 'pulp_last_updated__range_example', # String | pulp_last_updated__range
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List file remotes
  result = api_instance.list(opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling RemotesFileApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| name | [optional] 
 **name__in** | **String**| name__in | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_last_updated** | **String**| pulp_last_updated | [optional] 
 **pulp_last_updated__gt** | **String**| pulp_last_updated__gt | [optional] 
 **pulp_last_updated__gte** | **String**| pulp_last_updated__gte | [optional] 
 **pulp_last_updated__lt** | **String**| pulp_last_updated__lt | [optional] 
 **pulp_last_updated__lte** | **String**| pulp_last_updated__lte | [optional] 
 **pulp_last_updated__range** | **String**| pulp_last_updated__range | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**InlineResponse2005**](InlineResponse2005.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(file_file_remote_href, patchedfile_file_remote, opts)

Update a file remote

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::RemotesFileApi.new
file_file_remote_href = 'file_file_remote_href_example' # String | 
patchedfile_file_remote = PulpFileClient::PatchedfileFileRemote.new # PatchedfileFileRemote | 
opts = {
  name: 'name_example', # String | name
  name__in: 'name__in_example', # String | name__in
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_last_updated: 'pulp_last_updated_example', # String | pulp_last_updated
  pulp_last_updated__gt: 'pulp_last_updated__gt_example', # String | pulp_last_updated__gt
  pulp_last_updated__gte: 'pulp_last_updated__gte_example', # String | pulp_last_updated__gte
  pulp_last_updated__lt: 'pulp_last_updated__lt_example', # String | pulp_last_updated__lt
  pulp_last_updated__lte: 'pulp_last_updated__lte_example', # String | pulp_last_updated__lte
  pulp_last_updated__range: 'pulp_last_updated__range_example' # String | pulp_last_updated__range
}

begin
  #Update a file remote
  result = api_instance.partial_update(file_file_remote_href, patchedfile_file_remote, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling RemotesFileApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_remote_href** | **String**|  | 
 **patchedfile_file_remote** | [**PatchedfileFileRemote**](PatchedfileFileRemote.md)|  | 
 **name** | **String**| name | [optional] 
 **name__in** | **String**| name__in | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_last_updated** | **String**| pulp_last_updated | [optional] 
 **pulp_last_updated__gt** | **String**| pulp_last_updated__gt | [optional] 
 **pulp_last_updated__gte** | **String**| pulp_last_updated__gte | [optional] 
 **pulp_last_updated__lt** | **String**| pulp_last_updated__lt | [optional] 
 **pulp_last_updated__lte** | **String**| pulp_last_updated__lte | [optional] 
 **pulp_last_updated__range** | **String**| pulp_last_updated__range | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> FileFileRemoteResponse read(file_file_remote_href, opts)

Inspect a file remote

 FileRemote represents an external source of File Content.  The target url of a FileRemote must contain a file manifest, which contains the metadata for all files at the source.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::RemotesFileApi.new
file_file_remote_href = 'file_file_remote_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a file remote
  result = api_instance.read(file_file_remote_href, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling RemotesFileApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_remote_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**FileFileRemoteResponse**](FileFileRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(file_file_remote_href, file_file_remote, opts)

Update a file remote

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::RemotesFileApi.new
file_file_remote_href = 'file_file_remote_href_example' # String | 
file_file_remote = PulpFileClient::FileFileRemote.new # FileFileRemote | 
opts = {
  name: 'name_example', # String | name
  name__in: 'name__in_example', # String | name__in
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_last_updated: 'pulp_last_updated_example', # String | pulp_last_updated
  pulp_last_updated__gt: 'pulp_last_updated__gt_example', # String | pulp_last_updated__gt
  pulp_last_updated__gte: 'pulp_last_updated__gte_example', # String | pulp_last_updated__gte
  pulp_last_updated__lt: 'pulp_last_updated__lt_example', # String | pulp_last_updated__lt
  pulp_last_updated__lte: 'pulp_last_updated__lte_example', # String | pulp_last_updated__lte
  pulp_last_updated__range: 'pulp_last_updated__range_example' # String | pulp_last_updated__range
}

begin
  #Update a file remote
  result = api_instance.update(file_file_remote_href, file_file_remote, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling RemotesFileApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_remote_href** | **String**|  | 
 **file_file_remote** | [**FileFileRemote**](FileFileRemote.md)|  | 
 **name** | **String**| name | [optional] 
 **name__in** | **String**| name__in | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_last_updated** | **String**| pulp_last_updated | [optional] 
 **pulp_last_updated__gt** | **String**| pulp_last_updated__gt | [optional] 
 **pulp_last_updated__gte** | **String**| pulp_last_updated__gte | [optional] 
 **pulp_last_updated__lt** | **String**| pulp_last_updated__lt | [optional] 
 **pulp_last_updated__lte** | **String**| pulp_last_updated__lte | [optional] 
 **pulp_last_updated__range** | **String**| pulp_last_updated__range | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

